# coding: utf-8

from __future__ import absolute_import
from __future__ import unicode_literals

from django.core.validators import MinLengthValidator
from django.db import models

from .validators import snils_validator


class Person(models.Model):

    """Физ. лицо."""

    user = models.OneToOneField(
        'auth.User', verbose_name='Пользователь', on_delete=models.CASCADE)

    surname = models.CharField('Фамилия', max_length=50)
    first_name = models.CharField('Имя', max_length=50)
    patronymic = models.CharField('Отчество', max_length=50, blank=True)
    date_of_birth = models.DateField(u'Дата рождения', db_index=True)

    phone = models.CharField(
        u'Мобильный телефон +7', max_length=10, unique=True, blank=True,
        validators=[MinLengthValidator(10)])
    snils = models.CharField(
        u'СНИЛС', max_length=14, blank=True, validators=[snils_validator])

    @property
    def fullname(self):
        return ' '.join((
            self.surname, self.first_name, self.patronymic or ''
        )).strip()

    @property
    def display_phone(self):
        return u'+7 ({}) {}-{}-{}'.format(
            self.phone[0:3],
            self.phone[3:6],
            self.phone[6:8],
            self.phone[8:10],
        ) if self.phone else ''

    @property
    def display_date(self):
        return self.date_of_birth.strftime('%d.%m.%Y')
