# coding: utf-8

from __future__ import absolute_import
from __future__ import unicode_literals

import requests
import subprocess


class MockRequests(object):

    """Контекстный менеджер для подмены requests на django test client."""

    def __init__(self, client):
        self.client = client
        self.default_post = requests.post
        self.default_get = requests.get
        self.default_request = requests.request

    def __enter__(self):
        requests.post = self.client.post
        requests.get = self.client.get
        requests.request = self.client.request

    def __exit__(self, exc_type, exc_val, exc_tb):
        requests.post = self.default_post
        requests.get = self.default_get
        requests.request = self.default_request


class MockCheckOutput(object):

    """Контекстный менеджер для подмены check_output в subprocess."""

    def __init__(self, fn):
        self.fn = fn
        self.default_check_output = subprocess.check_output

    def __enter__(self):
        subprocess.check_output = self.fn

    def __exit__(self, exc_type, exc_val, exc_tb):
        subprocess.check_output = self.default_check_output
